summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorFrederic Peters <fpeters@entrouvert.com>2005-02-08 10:25:00 +0000
committerFrederic Peters <fpeters@entrouvert.com>2005-02-08 10:25:00 +0000
commite87dc10be14af2ae21e26089b17d78e65ddf9a22 (patch)
tree6ddcb9bf47fc6abaf5933916d6e08fa34a4fd27c
parentba097b51bc258e12413633e25c55a85e1281e043 (diff)
variables and functions shouldn't have the same names
-rw-r--r--lasso/id-ff/lecp.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/lasso/id-ff/lecp.c b/lasso/id-ff/lecp.c
index 25c1b2b6..3ae0e191 100644
--- a/lasso/id-ff/lecp.c
+++ b/lasso/id-ff/lecp.c
@@ -46,7 +46,7 @@ lasso_lecp_build_authn_request_envelope_msg(LassoLecp *lecp)
{
LassoProfile *profile;
gchar *assertionConsumerServiceURL;
- xmlNode *message;
+ xmlNode *msg;
xmlOutputBuffer *buf;
xmlCharEncodingHandler *handler;
@@ -77,17 +77,17 @@ lasso_lecp_build_authn_request_envelope_msg(LassoLecp *lecp)
LASSO_PROFILE(lecp)->server->private_key;
LASSO_SAMLP_REQUEST_ABSTRACT(lecp->authnRequestEnvelope->AuthnRequest)->certificate_file =
LASSO_PROFILE(lecp)->server->certificate;
- message = lasso_node_get_xmlNode(LASSO_NODE(lecp->authnRequestEnvelope), FALSE);
+ msg = lasso_node_get_xmlNode(LASSO_NODE(lecp->authnRequestEnvelope), FALSE);
- /* message is not SOAP but straight XML */
+ /* msg is not SOAP but straight XML */
handler = xmlFindCharEncodingHandler("utf-8");
buf = xmlAllocOutputBuffer(handler);
- xmlNodeDumpOutput(buf, NULL, message, 0, 0, "utf-8");
+ xmlNodeDumpOutput(buf, NULL, msg, 0, 0, "utf-8");
xmlOutputBufferFlush(buf);
profile->msg_body = g_strdup(buf->conv ? buf->conv->content : buf->buffer->content);
xmlOutputBufferClose(buf);
- xmlFreeNode(message);
+ xmlFreeNode(msg);
if (profile->msg_body == NULL) {
message(G_LOG_LEVEL_CRITICAL,